%define module unionfs
%define version 1.4
%define release	%mkrel 2

Summary: A Stackable Unification File System
Name: %{module}
Version: %{version}
Release: %{release}
Source0: http://download.filesystems.org/unionfs/OLD/unionfs-1.x/%{name}-%{version}.tar.gz
Source1: unionfs-dkms.conf
# fix build with 2.6.22 and apparmor, from 2008.0 update kernel
Patch0: unionfs-1.4-2.6.22-apparmor.patch
# adapt to kmem_cache_create prototype (and new arguments order...)
Patch1: unionfs-1.4-kmem_cache_create.patch
# do not use security hooks, use VFS helpers instead
# rediffed from "[PATCH 2/8] Unionfs: cleanup permission checking code"
Patch2: unionfs-1.4-security_hooks.patch
# do not trigger BUG() in notify_change when setting mode attributes
# rediffed from "[PATCH 4/7] unionfs: fix unionfs_create and unionfs_setattr to handle ATTR_KILL_S*ID"
Patch3: unionfs-1.4-attr_mode_notify_change.patch
License: GPL
Group: System/Kernel and hardware
URL: http://www.filesystems.org/project-unionfs.html
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Unionfs is a Stackable Unification File System.
This project builds a stackable unification file system, which can
appear to merge the contents of several directories (branches), while
keeping their physical content separate. Unionfs is useful for unified
source tree management, merged contents of split CD-ROM, merged
separate software package directories, data grids, and more. Unionfs
allows any mix of read-only and read-write branches, as well as
insertion and deletion of branches anywhere in the fan-out. To
maintain unix semantics, Unionfs handles elimination of duplicates,
partial-error conditions, and more. Unionfs is part of the larger FiST
project.

%package -n dkms-%{name}
Group: System/Kernel and hardware
Summary: Dkms module for the unionfs module
Requires(post): dkms
Requires(preun): dkms

%description -n dkms-%{name}
Unionfs is a Stackable Unification File System.
This package contains the kernel module.

%prep
%setup -q
%patch0 -p1
%patch1 -p1 -b .kmem_cache_create
%patch2 -p1 -b .security_hooks
%patch3 -p1 -b .attr_mode_notify_change
perl -p -e 's/\@VERSION@/%{version}/' < %{SOURCE1} > dkms.conf

%build

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_mandir}/man4
install man/%{name}.4 %{buildroot}%{_mandir}/man4
mkdir -p %{buildroot}/usr/src/%{module}-%{version}.%{release}/
install -m 644 dkms.conf %{buildroot}/usr/src/%{module}-%{version}.%{release}/dkms.conf
tar c . | tar x -C %{buildroot}/usr/src/%{module}-%{version}.%{release}/

%clean
rm -rf %{buildroot}

%files -n dkms-%{name}
%defattr(-,root,root)
%attr(0755,root,root) /usr/src/%{module}-%{version}.%{release}/
%{_mandir}/man4/%{name}.4*

%post -n dkms-%{name}
set -x
/usr/sbin/dkms --rpm_safe_upgrade add -m %{module} -v %{version}.%{release}
/usr/sbin/dkms --rpm_safe_upgrade build -m %{module} -v %{version}.%{release}
/usr/sbin/dkms --rpm_safe_upgrade install -m %{module} -v %{version}.%{release}

%preun -n dkms-%{name}
set -x
/usr/sbin/dkms --rpm_safe_upgrade remove -m %{module} -v %{version}.%{release} --all


%changelog
* Wed Jun 18 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.4-2mdv2009.0
+ Revision: 225898
- rebuild

* Fri Jan 11 2008 Olivier Blin <oblin@mandriva.com> 1.4-1mdv2008.1
+ Revision: 148691
- do not trigger BUG() in notify_change when setting mode attributes
- do not use security hooks, use VFS helpers instead
- adapt to kmem_cache_create prototype (and new arguments order...)
- apply 2.6.22 and apparmor fixes from 2008.0 update kernel
- 1.4
- update URL
- do not buildrequire e2fsprogs-devel, tools are in a separate package
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Oct 02 2007 Olivier Blin <oblin@mandriva.com> 1.3-4mdv2008.0
+ Revision: 94490
- update to new version


* Sun Feb 04 2007 Olivier Blin <oblin@mandriva.com> 1.3-3mdv2007.0
+ Revision: 116122
- do not conflict with unionfs-tools anymore

  + Bogdano Arendartchuk <bogdano@mandriva.com>
    - moved dkms post/postun deps to subpackage

* Mon Nov 13 2006 Olivier Blin <oblin@mandriva.com> 1.3-2mdv2007.1
+ Revision: 83837
- remove hardcoded make command line in dkms config file

* Mon Nov 13 2006 Olivier Blin <oblin@mandriva.com> 1.3-1mdv2007.1
+ Revision: 83806
- 1.3
- remove tools subpackage, it's now in unionfs-utils
- Import unionfs

* Tue May 16 2006 Olivier Blin <oblin@mandriva.com> 1.1.4-1mdk
- New release 1.1.4

* Thu Jan 26 2006 Olivier Blin <oblin@mandriva.com> 1.1.2-1mdk
- 1.1.2

* Thu Jan 19 2006 Olivier Blin <oblin@mandriva.com> 1.1.1-1.20060117.1mdk
- CVS snapshot (20060112)
- buildrequires e2fsprogs-devel
- add missing changelog entry

* Fri Jan 13 2006 Olivier Blin <oblin@mandriva.com> 1.1.1-1.20051124.1mdk
- CVS snapshot (20051124)

* Wed Nov 09 2005 Olivier Blin <oblin@mandriva.com> 1.1.1-1mdk
- initial release

